@@ -3,7 +3,7 @@ type = "counts"
 Sest.method = "average"
 cases = 5
 N = 50
-sites = 10
+M = 10
 n = 7
 m = 5
 k = 20
@@ -14,7 +14,7 @@ useParallel = FALSE
 model = "single.factor"
 
 result <- prep_data(data = epiDat, type, Sest.method,
-                    cases, N, sites,
+                    cases, N, M,
                     n, m, k,
                     transformation, method,
                     dummy, useParallel,
@@ -22,9 +22,9 @@ result <- prep_data(data = epiDat, type, Sest.method,
 
 test_that("prep_data() returns an object with certain characteristics",{
   testthat::expect_s3_class(result, "ecocbo_data")
-  testthat::expect_equal(ncol(result$Results), 8)
+  testthat::expect_equal(ncol(result$Results), 6)
   testthat::expect_error(prep_data(epiDat, n = 1, m, k, useParallel = FALSE), "larger")
-  testthat::expect_error(prep_data(epiDat, n = n, m = 1, k, useParallel = FALSE), "larger")
+  testthat::expect_error(prep_data(epiDat, n = 1, m = 1, k, useParallel = FALSE), "larger")
   testthat::expect_equal(max(result$Results[,2]), k)
 })
 
